#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-hamt
version:              1.2.2.1
visibility:           public
id:                   stm-hamt-1.2.2.1-CvMFNVdzUTb3PaB2fCk2Tu
key:                  stm-hamt-1.2.2.1-CvMFNVdzUTb3PaB2fCk2Tu
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-hamt
synopsis:             STM-specialised Hash Array Mapped Trie
description:
    A low-level data-structure,
    which can be used to implement higher-level interfaces like
    hash-map and hash-set.
    Such implementations are presented by the
    <http://hackage.haskell.org/package/stm-containers stm-containers>.

category:             Data Structures, STM, Concurrency
abi:                  b4b0bf8e7d0b54300f08b027f9661411
exposed:              True
exposed-modules:      StmHamt.Hamt StmHamt.SizedHamt
hidden-modules:
    StmHamt.Constructors.Branch StmHamt.Focuses StmHamt.IntOps
    StmHamt.ListT StmHamt.Prelude StmHamt.Types StmHamt.UnfoldlM

import-dirs:          /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stm-hamt-1.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-hamt
hs-libraries:         HSstm-hamt-1.2.2.1-CvMFNVdzUTb3PaB2fCk2Tu
depends:
    base-4.18.2.1 deferred-folds-0.9.18.10-7Qy7YAuzRMZGNMkJd3lzL7
    focus-1.0.3.2-K4r8d6TYSaL8JgI7TgFd9X
    hashable-1.4.7.0-KYRxVQLzygQHnYjqLKyJPN
    list-t-1.0.5.7-5wiNHt4HfJY6yigEbdj2d7
    primitive-0.9.1.0-MBLhlhjxKECZedf7vLmE9
    primitive-extras-0.10.2.2-959ZJcmpAYCDMmvP40fyye
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-stm-hamt/html/stm-hamt.haddock
haddock-html:         /usr/share/doc/haskell-stm-hamt/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

